======================
Output data from pyxrf
======================

* After pixel fitting is done. Data is saved into hdf5 file automatically.

* You may also output fitted data to tiff (txt) format by clicking the button
  "Save to tiff" ("Save to txt") at the bottom of Fit panel.
